@@ -315,7 +315,7 @@ Ext.define('MP.data.MetaData', {
                     triggerAction: 'all',
                     typeAhead: true,
                     forceSelection: true,
-                    allowBlank: false,
+                    allowBlank: true,
                     minChars: 0
                 };
             } else if(info.lookup && info.lookup.url) {
@@ -416,7 +416,7 @@ Ext.define('MP.data.MetaData', {
                     triggerAction: 'all',
                     typeAhead: true,
                     forceSelection: true,
-                    allowBlank: false,
+                    allowBlank: true,
                     minChars: 0,
                     pageSize: lup.pageSize,
                     listConfig: listConfig
